@@ -44,33 +44,33 @@ setMethod("write_quadtree", signature(x = "character", y = "Quadtree"),
   }
 )
 
-# #' @name write_quadtree_ptr
-# #' @aliases write_quadtree_ptr,character,Quadtree-method
-# #' @title Read/write a \code{Quadtree}
-# #' @description This is for debugging only, and users should never need to use
-# #'   this function - use \code{\link{write_quadtree}()} instead.
-# #'   \code{\link{write_quadtree}()} serializes the \code{CppQuadtree} object
-# #'   (note that the underlying C++ object is actually called
-# #'   \code{QuadtreeWrapper}, but it is exposed to R as \code{CppQuadtree}) stored
-# #'   in the \code{ptr} slot of \code{\link{Quadtree}}. 
-# #'   
-# #'   This function, however, serializes only the \code{Quadtree} object contained by the
-# #'   \code{QuadtreeWrapper}.
-# #' @param x character; the filepath to read from or write to
-# #' @param y a \code{\link{Quadtree}}
-# #' @return
-# #' no return value
-# #' @examples
-# #' library(quadtree)
-# #' data(habitat)
-# #'
-# #' qt <- quadtree(habitat, .1)
-# #'
-# #' path <- tempfile(fileext = "qtree")
-# #' write_quadtree_ptr(path, qt)
-# #' @export
-# setMethod("write_quadtree_ptr", signature(x = "character", y = "Quadtree"),
-#   function(x, y) {
-#     writeQuadtreePtr(y@ptr, x)
-#   }
-# )
+#' @name write_quadtree_ptr
+#' @aliases write_quadtree_ptr,character,Quadtree-method
+#' @title Read/write a \code{Quadtree}
+#' @description This is for debugging only, and users should never need to use
+#'   this function - use \code{\link{write_quadtree}()} instead.
+#'   \code{\link{write_quadtree}()} serializes the \code{CppQuadtree} object
+#'   (note that the underlying C++ object is actually called
+#'   \code{QuadtreeWrapper}, but it is exposed to R as \code{CppQuadtree}) stored
+#'   in the \code{ptr} slot of \code{\link{Quadtree}}.
+#'
+#'   This function, however, serializes only the \code{Quadtree} object contained by the
+#'   \code{QuadtreeWrapper}.
+#' @param x character; the filepath to read from or write to
+#' @param y a \code{\link{Quadtree}}
+#' @return
+#' no return value
+#' @examples
+#' library(quadtree)
+#' data(habitat)
+#'
+#' qt <- quadtree(habitat, .1)
+#'
+#' path <- tempfile(fileext = "qtree")
+#' write_quadtree_ptr(path, qt)
+#' @export
+setMethod("write_quadtree_ptr", signature(x = "character", y = "Quadtree"),
+  function(x, y) {
+    writeQuadtreePtr(y@ptr, x)
+  }
+)
